<?php

namespace Schaffen\SerasaRemessa\Http\Advanced\PF\Blocks;

use Schaffen\SerasaRemessa\Utils\Record;
use Schaffen\SerasaRemessa\Utils\RecordColumn;
use Schaffen\SerasaRemessa\Utils\Util;
use Exception;

class MainBlock extends Record {
	/**
     * @var array Lista de colunas esperadas para o bloco
     */
	protected $templateColumns = [
        [
           "name" => "product_code", 
           "position" => 1, 
           "size" => 4, 
           "type" => RecordColumn::TYPE_ALPHANUMERIC 
        ], 
        [
           "name" => "caller_station", 
           "position" => 5, 
           "size" => 6, 
           "type" => RecordColumn::TYPE_ALPHANUMERIC 
        ], 
        [
           "name" => "document", 
           "position" => 11, 
           "size" => 15, 
           "type" => RecordColumn::TYPE_NUMERIC 
        ], 
        [
           "name" => "person_type", 
           "position" => 26, 
           "size" => 1, 
           "type" => RecordColumn::TYPE_ALPHANUMERIC 
        ], 
        [
           "name" => "base_cons", 
           "position" => 27, 
           "size" => 6, 
           "type" => RecordColumn::TYPE_ALPHANUMERIC 
        ], 
        [
           "name" => "modality", 
           "position" => 33, 
           "size" => 2, 
           "type" => RecordColumn::TYPE_ALPHANUMERIC 
        ], 
        [
           "name" => "consult_value", 
           "position" => 35, 
           "size" => 7, 
           "type" => RecordColumn::TYPE_NUMERIC 
        ], 
        [
           "name" => "cost_center", 
           "position" => 42, 
           "size" => 12, 
           "type" => RecordColumn::TYPE_ALPHANUMERIC 
        ], 
        [
           "name" => "codified", 
           "position" => 54, 
           "size" => 1, 
           "type" => RecordColumn::TYPE_ALPHANUMERIC 
        ], 
        [
           "name" => "register_quantity", 
           "position" => 55, 
           "size" => 2, 
           "type" => RecordColumn::TYPE_NUMERIC 
        ], 
        [
           "name" => "conversation", 
           "position" => 57, 
           "size" => 1, 
           "type" => RecordColumn::TYPE_ALPHANUMERIC 
        ], 
        [
           "name" => "role", 
           "position" => 58, 
           "size" => 3, 
           "type" => RecordColumn::TYPE_ALPHANUMERIC 
        ], 
        [
           "name" => "cosult_type", 
           "position" => 61, 
           "size" => 1, 
           "type" => RecordColumn::TYPE_ALPHANUMERIC 
        ], 
        [
           "name" => "update", 
           "position" => 62, 
           "size" => 1, 
           "type" => RecordColumn::TYPE_ALPHANUMERIC 
        ], 
        [
           "name" => "filler_1", 
           "position" => 63, 
           "size" => 42, 
           "type" => RecordColumn::TYPE_ALPHANUMERIC 
        ], 
        [
           "name" => "check_quantity", 
           "position" => 105, 
           "size" => 2, 
           "type" => RecordColumn::TYPE_NUMERIC 
        ], 
        [
           "name" => "addr_tel", 
           "position" => 107, 
           "size" => 1, 
           "type" => RecordColumn::TYPE_ALPHANUMERIC 
        ], 
        [
           "name" => "filler_2", 
           "position" => 108, 
           "size" => 7, 
           "type" => RecordColumn::TYPE_ALPHANUMERIC 
        ], 
        [
           "name" => "update_tel_9", 
           "position" => 115, 
           "size" => 1, 
           "type" => RecordColumn::TYPE_NUMERIC 
        ], 
        [
           "name" => "account", 
           "position" => 116, 
           "size" => 10, 
           "type" => RecordColumn::TYPE_NUMERIC 
        ], 
        [
           "name" => "account_digit", 
           "position" => 126, 
           "size" => 1, 
           "type" => RecordColumn::TYPE_NUMERIC 
        ], 
        [
           "name" => "agency", 
           "position" => 127, 
           "size" => 4, 
           "type" => RecordColumn::TYPE_NUMERIC 
        ], 
        [
           "name" => "alert", 
           "position" => 131, 
           "size" => 1, 
           "type" => RecordColumn::TYPE_ALPHANUMERIC 
        ], 
        [
           "name" => "logon", 
           "position" => 132, 
           "size" => 8, 
           "type" => RecordColumn::TYPE_ALPHANUMERIC 
        ], 
        [
           "name" => "filler_3", 
           "position" => 140, 
           "size" => 1, 
           "type" => RecordColumn::TYPE_ALPHANUMERIC 
        ], 
        [
           "name" => "response", 
           "position" => 141, 
           "size" => 1, 
           "type" => RecordColumn::TYPE_NUMERIC 
        ], 
        [
           "name" => "commitment_period", 
           "position" => 142, 
           "size" => 1, 
           "type" => RecordColumn::TYPE_NUMERIC 
        ], 
        [
           "name" => "address_period", 
           "position" => 143, 
           "size" => 1, 
           "type" => RecordColumn::TYPE_NUMERIC 
        ], 
        [
           "name" => "filler_4", 
           "position" => 144, 
           "size" => 48, 
           "type" => RecordColumn::TYPE_NUMERIC 
        ], 
        [
           "name" => "commitment_quantity", 
           "position" => 192, 
           "size" => 2, 
           "type" => RecordColumn::TYPE_NUMERIC 
        ], 
        [
           "name" => "negatives", 
           "position" => 194, 
           "size" => 1, 
           "type" => RecordColumn::TYPE_ALPHANUMERIC 
        ], 
        [
           "name" => "check", 
           "position" => 195, 
           "size" => 1, 
           "type" => RecordColumn::TYPE_ALPHANUMERIC 
        ], 
        [
           "name" => "consultation_date", 
           "position" => 196, 
           "size" => 8, 
           "type" => RecordColumn::TYPE_ALPHANUMERIC 
        ], 
        [
           "name" => "consultation_time", 
           "position" => 204, 
           "size" => 6, 
           "type" => RecordColumn::TYPE_ALPHANUMERIC 
        ], 
        [
           "name" => "total_records", 
           "position" => 210, 
           "size" => 4, 
           "type" => RecordColumn::TYPE_ALPHANUMERIC 
        ], 
        [
           "name" => "number_of_records", 
           "position" => 214, 
           "size" => 4, 
           "type" => RecordColumn::TYPE_NUMERIC 
        ], 
        [
           "name" => "cod_tab", 
           "position" => 218, 
           "size" => 4, 
           "type" => RecordColumn::TYPE_NUMERIC 
        ], 
        [
           "name" => "filler_5", 
           "position" => 222, 
           "size" => 176, 
           "type" => RecordColumn::TYPE_ALPHANUMERIC 
        ], 
        [
           "name" => "recheck_accessed", 
           "position" => 398, 
           "size" => 1, 
           "type" => RecordColumn::TYPE_ALPHANUMERIC 
        ], 
        [
           "name" => "recheck_occurrence", 
           "position" => 399, 
           "size" => 1, 
           "type" => RecordColumn::TYPE_ALPHANUMERIC 
        ], 
        [
           "name" => "filler_6", 
           "position" => 400, 
           "size" => 1, 
           "type" => RecordColumn::TYPE_ALPHANUMERIC 
        ] 
	]; 

    public function __construct($values = null) {
        $this->createColumns();
        
        if($values !== null) {
            $this->validate($values);
            $this->setValues($values);
        }
    }

    public function validate($values) {
		if(empty($values['document'])) {
			throw new Exception("Necessário informar o documento a ser consultado.");
		}
    }

    /**
     * @param $values lista de valores no formato, chave => valor
     */
    private function setValues($values) {
		$values["product_code"] = "B49C";
		$values["caller_station"] = "      ";
		$values["person_type"] = "F";
		$values["base_cons"] = "C     ";
		$values["modality"] = "  ";
		$values["consult_value"] = "0000000";
		$values["cost_center"] = "            ";
		$values["codified"] = " ";
		$values["register_quantity"] = "  ";
		$values["conversation"] = " ";
		$values["role"] = "INI";
		$values["cosult_type"] = "A";
		$values["update"] = "N";
		$values["filler_1"] = "";
		$values["check_quantity"] = "00";
		$values["addr_tel"] = "S";
		$values["filler_2"] = "";
		$values["update_tel_9"] = "S";
		$values["account"] = "0000000000";
		$values["account_digit"] = "0";
		$values["agency"] = "0000";
		$values["alert"] = " ";
		$values["logon"] = "        ";
		$values["filler_3"] = " ";
		$values["response"] = " ";
		$values["commitment_period"] = " ";
		$values["address_period"] = " ";
		$values["filler_4"] = "";
		$values["commitment_quantity"] = "00";
		$values["negatives"] = " ";
		$values["check"] = " ";
		$values["consultation_date"] = "        ";
		$values["consultation_time"] = "      ";
		$values["total_records"] = "0000";
		$values["number_of_records"] = "0000";
		$values["cod_tab"] = "0000";
		$values["filler_5"] = "";
		$values["recheck_accessed"] = " ";
		$values["recheck_occurrence"] = " ";
		$values["filler_6"] = " ";

      $this->setColumnsValues($values);
   }
}